pub(crate) fn root_aggregate_ty(ty: &Ty) -> Result<&Ty, LowerError>Expand description
Return the aggregate type reachable through a direct local or reference local.
pub(crate) fn root_aggregate_ty(ty: &Ty) -> Result<&Ty, LowerError>Return the aggregate type reachable through a direct local or reference local.