fn find_exported_function(
module: &Module,
export_name: &str,
) -> Option<FunctionId>Expand description
Find a function export by name and return its function ID.
fn find_exported_function(
module: &Module,
export_name: &str,
) -> Option<FunctionId>Find a function export by name and return its function ID.