fn update_heap_base_global(
module: &mut Module,
heap_base_global: GlobalId,
heap_base: u32,
) -> Result<(), LowerError>Expand description
Update the exported heap base after injecting new literal data segments.
fn update_heap_base_global(
module: &mut Module,
heap_base_global: GlobalId,
heap_base: u32,
) -> Result<(), LowerError>Update the exported heap base after injecting new literal data segments.