Enum LoweringMode
pub enum LoweringMode {
Direct,
}Expand description
Lowering strategy used by code generators for a runtime function.
Variants
Direct
Emit a direct host call with no adapter trampoline.