pub(crate) fn runtime_tracked_alloc_function(
runtime: &RuntimeFunctions,
) -> Result<RuntimeFunction, LowerError>Expand description
Return the tracked runtime allocator descriptor used by generated code.
pub(crate) fn runtime_tracked_alloc_function(
runtime: &RuntimeFunctions,
) -> Result<RuntimeFunction, LowerError>Return the tracked runtime allocator descriptor used by generated code.